/* volume.C

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#include "system.h"

#include "volume.h"
#include "volumeBase.h"
#include "tableDataProxy.h"

Volume::
Volume() {
}

Volume::
Volume(int volume_id) {
  Dataset new_data;
  new_data[TI_volumes] = TableDataProxy(TI_volumes, volume_id);
  set_ptr(VolumeBase::make_volume(new_data));
}

Volume::
Volume(const Dataset &data, int volume_id) {
  Dataset new_data(data);
  new_data[TI_volumes] = TableDataProxy(TI_volumes, volume_id);
  set_ptr(VolumeBase::make_volume(new_data));
}

Volume::
Volume(const Dataset &data, const TableDataProxy &volume) {
  Dataset new_data(data);
  new_data[TI_volumes] = volume;
  set_ptr(VolumeBase::make_volume(new_data));
}

bool Volume::
is_valid() const {
  return (ReferenceCountProxy::get_ptr() != NULL);
}

string Volume::
get_description() const {
  return get_ptr()->get_description();
}

string Volume::
get_definition() const {
  return get_ptr()->get_definition();
}

int Volume::
get_volume_id() const {
  return get_ptr()->get_volume_id();
}

bool Volume::
exists() const {
  return get_ptr()->exists();
}

bool Volume::
can_read_files() const {
  return get_ptr()->can_read_files();
}

bool Volume::
can_store_files() const {
  return get_ptr()->can_store_files();
}

string Volume::
get_filename(const string &rel_filename) {
  return get_ptr()->get_filename(rel_filename);
}

string Volume::
prepare_write_file(const string &basename) {
  return get_ptr()->prepare_write_file(basename);
}

string Volume::
close_write_file(const string &full_pathname, const string &basename) {
  return get_ptr()->close_write_file(full_pathname, basename);
}

string Volume::
store_file(const string &full_pathname, const string &basename, 
	   bool leave_orig) {
  return get_ptr()->store_file(full_pathname, basename, leave_orig);
}

void Volume::
read_db() {
  get_ptr()->read_db();
}

VolumeBase *Volume::
get_ptr() const {
  VolumeBase *ptr = (VolumeBase *)ReferenceCountProxy::get_ptr();
  assert(ptr != NULL);
  return ptr;
}
