/* songPlayerControls.h

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#ifndef SONGPLAYERCONTROLS_H
#define SONGPLAYERCONTROLS_H

#include "sfClient.h"
#include "dataset.h"

#include <gtk--.h>

class CDReader;
class TableDataProxy;

class SongPlayerControls : public Gtk_Frame {
public:
  SongPlayerControls(const Dataset &data);
  ~SongPlayerControls();

  void set_song(TableDataProxy song,
		CDReader *cd_reader = (CDReader *)NULL,
		int song_index = -1);
  int get_current_song() const;

  void rewind();
  void stop();
  void play();

  bool is_playing() const;
  
  // The signal returned by this function will be thrown whenever the
  // song reaches the end and stops naturally.
  Signal0 &get_end_signal();

private:
  void got_ready();
  void got_start_playing();
  void got_interrupt();
  void got_update_time(double time);
  void got_rstart_state(bool flag);
  void user_update_position();
  void rewind_button_clicked();
  void stop_button_clicked();
  void play_button_clicked();

  void make_pixmaps();
  void layout_window();
  void set_overall_insensitive(bool flag);
  void set_slider_insensitive(bool flag);

  Gtk_HBox _box0;
  Gtk_VBox _box1;
  Gtk_Adjustment _play_adjustment;
  Gtk_HScale _play_position;
  Gtk_HBox _box2;
  Gtk_Button _rewind_button;
  Gtk_Button _stop_button;
  Gtk_Button _play_button;
  Gtk_Pixmap _rewind_pixmap;
  Gtk_Pixmap _stop_pixmap;
  Gtk_Pixmap _play_pixmap;

  static Gdk_Pixmap _rewind_gdk_pixmap;
  static Gdk_Bitmap _rewind_gdk_mask;
  static Gdk_Pixmap _stop_gdk_pixmap;
  static Gdk_Bitmap _stop_gdk_mask;
  static Gdk_Pixmap _play_gdk_pixmap;
  static Gdk_Bitmap _play_gdk_mask;
  static bool _got_pixmaps;

  string _filename;
  double _length;

  bool _internal_update;
  bool _playing;
  int _current_song_index;
  SFClient _client;

  Dataset _data;
};

#endif
